#
# spec file for package python3-testtools
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# A build cycle exists between python-extras and python-testtools. Thus, only
# enable testing with a build conditional (off by default):

Name:           python3-testtools
Version:        2.2.0
Release:        2.6
Summary:        Extensions to the Python Standard Library Unit Testing Framework
License:        MIT
Group:          Development/Languages/Python
Url:            https://launchpad.net/testtools
Source:         https://files.pythonhosted.org/packages/source/t/testtools/testtools-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-extras
BuildRequires:  python3-pbr
BuildRequires:  python3-pyrsistent
BuildRequires:  python3-python-mimeparse
BuildRequires:  python3-setuptools
BuildRequires:  python3-traceback2
BuildRequires:  python3-unittest2
Requires:       python3-extras
Requires:       python3-fixtures
Requires:       python3-pyrsistent
Requires:       python3-python-mimeparse
Requires:       python3-traceback2
Requires:       python3-unittest2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
testtools is a set of extensions to the Python standard library's unit testing
framework. These extensions have been derived from many years of experience
with unit testing in Python and come from many different sources. testtools
also ports recent unittest changes all the way back to Python 2.4.

%prep
%setup -q -n testtools-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

# Tests cause dependency loops with python3-fixtures and python3-testscenarios, so run them in doc subpackage

%files
%defattr(-,root,root,-)
%doc LICENSE NEWS README.rst
%{python3_sitelib}/testtools
%{python3_sitelib}/testtools-%{version}-py%{py3_ver}.egg-info

%changelog
* Wed May 25 2016 arun@gmx.de
- update to version 2.2.0:
  * Twisted support code uses "inlineCallbacks" rather than the
    deprecated "deferredGenerator".  (Tristan Seligmann)
* Thu May 19 2016 toddrme2178@gmail.com
- Split documentation into own subpackage to speed up build.
* Sun May 15 2016 arun@gmx.de
- update to version 2.1.0:
  * "TestResult" objects that don't implement "stop"/"shouldStop" are
    now handled sanely.  (Jonathan Lange)
  * New "Always" and "Never" matchers. (Tristan Seligmann, #947026)
  * Fixed example in "failed" docstring. (Jonathan Lange, Github #208)
  * Rather than explicitly raising a "KeyboardInterrupt" if we get no
    result from a "Deferred", we tell the test result to stop running
    tests and report the lack of result as a test error. This ought to
    make weird concurrency interaction bugs easier to
    understand. (Jonathan Lange)
  * Introduce the unique_text_generator generator function. Similar to
    the getUniqueString() method, except it creates unique unicode
    text strings.  (Brant Knudson)
  * Previously, when gathering details caused by a setUp() failure, a
    traceback occurred if the fixture used the newer _setUp().  This
    had the side effect of not clearing up fixtures nor gathering
    details properly.  This is now fixed. (Julian Edwards, #1469759)
  * New "Warnings" matcher, and "WarningMessage" and "IsDeprecated"
    functions for matching emitted warnings. (Jonathan Jacobs, Github
    [#223])
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Wed Mar 16 2016 toddrme2178@gmail.com
- Break dependency loops with python3-fixtures and
  python3-testscenarios by disabling unit tests.
* Thu Feb  4 2016 arun@gmx.de
- specfile:
  * requrie python3-fixtures
- update to version 2.0.0:
  * "AsynchronousDeferredRunTest" now has "suppress_twisted_logging"
    and "store_twisted_logs" parameters that can be used to override
    the default logging behaviour.  (Jonathan Lange, #942785)
  * New fixture "CaptureTwistedLogs" that can be used with
    "AsynchronousDeferredRunTest" to attach a detail containing
    everything logged to Twisted during the test run.  (Jonathan
    Lange, #1515362)
  * Python 2.6 and 3.2 are no longer supported. If you want to use
    either of these versions of Python, use testtools 1.9.0. (Jonathan
    Lange)
  * Make "fixtures" a real dependency, not just a test
    dependency. (Jonathan Lange)
* Wed Feb  3 2016 toddrme2178@gmail.com
- python3-pyrsistent is also a runtime requirement.
* Tue Jan 26 2016 arun@gmx.de
- specfile:
  * update copyright year
  * require pyrsistent, testscenarios for tests
- update to version 1.9.0:
  * Many new fixes in this branch, including lots of work around
    Twisted support.
  * This is the first release that explicitly supports Python 3.5 and
    the last release that supports Python 2.6 or 3.2.
  * Improvements
    + Python 3.5 added to the list of supported platforms. (Jonathan
    Lange)
    + "MatchesListwise" has more informative error when lengths don't
    match. (Jonathan Lange)
    + The short form of errors for failed binary comparisions will now
    put the expected value on the _right_. This means that
    "assertThat(2, Equals(3))" will raise an error saying "2 !=
    3". (Jonathan Lange, #1525227)
    + Tests for "assertRaisesRegexp". (Julia Varlamova, Jonathan
    Lange)
    + Tests that customize "skipException" no longer get tracebacks
    for skipped tests.  (Jonathan Lange, #1518101)
    + A failing "expectThat" now fails tests run with
    "AsynchronousDeferredRunTest".  (Jonathan Lange, #1532452)
    + New "testtools.twistedsupport" package that collects all of our
    Twisted support code in one place, including that currently
    available under "testtools.deferredruntest".  (Jonathan Lange)
    + New matchers for testing "Deferred" code: "failed", "succeeded",
    and "has_no_result".  (Jonathan Lange, Tristan Seligmann,
    [#1369134])
    + "TestCase" objects can now be run twice. All internal state is
    reset between runs. In particular, testtools tests can now be run
    with "trial -u".  (Jonathan Lange, #1517879)
    + Fixed bug where if an asynchronous "Deferred" test times out but
    the "Deferred" then fires, the entire test run would abort with
    "KeyboardInterrupt", failing the currently running test.
    (Jonathan Lange, James Westby)
  * Changes
    + Add a new test dependency of testscenarios. (Robert Collins)
    + "addCleanup" can now only be called within a test run.
    (Jonathan Lange)
    + "TestCase.skip" deprecated. Use "skipTest" instead. (Jonathan
    Lange, #988893)
    + Getting "expected" or "observed" attributes from binary
    comparison mismatches (e.g. "Equals(2).match(3).expected") is now
    deprecated. (Jonathan Lange)
    + Last release of testtools to support Python 3.2. (Jonathan
    Lange)
    + Last release of testtools to support Python 2.6. (Jonathan
    Lange)
    + Report on all duplicate test ids when sorting test suites that
    contain duplicate ids.  (Thomas Bechtold, Jonathan Lange,
    [#1390082])
    + Add "readthedocs-requirements.txt" so readthedocs.org can build
    the Twisted API documentation. (Jonathan Lange)
* Sat Nov 14 2015 arun@gmx.de
- update to version 1.8.1:
  * Documented more explicitly how to build and install testtools in
    the hacking documentation. (Thomi Richards)
  * "deferredruntest" now works with Twisted 15.1.0 and later.  (Colin
    Watson, #1488710)
* Mon Oct 26 2015 toddrme2178@gmail.com
- Use upstream unit test command
* Sun May 10 2015 arun@gmx.de
- specfile:
  * added pbr
- update to version 1.8.0:
  * AsynchronousDeferredRunTest now correctly attaches the test log.
    Previously it attached an empty file. (Colin Watson)
* Wed Mar 11 2015 arun@gmx.de
- specfile:
  * added traceback2 requirement
- update to version 1.7.1:
  * Building a wheel on Python 3 was missing "_compat2x.py" needed
    for Python2.  This was a side effect of the fix to bug #941958,
    where we fixed a cosmetic error. (Robert Collins, #1430534)
  * During reporting in "TextTestResult" now always uses "ceil"
    rather than depending on the undefined rounding behaviour in
    string formatting.  (Robert Collins)
- changes from version 1.7.0:
  * Empty attachments to tests were triggering a file payload of None
    in the "ExtendedToStreamDecorator" code, which caused multiple
    copies of attachments that had been output prior to the empty one.
    (Robert Collins, #1378609)
- changes from version 1.6.1:
  * Fix installing when "extras" is not already installed. Our guards
    for the absence of unittest2 were not sufficient.  (Robert
    Collins, #1430076)
- changes from version 1.6.0:
  * "testtools.run" now accepts "--locals" to show local variables in
    tracebacks, which can be a significant aid in debugging. In doing
    so we've removed the code reimplementing linecache and traceback
    by using the new traceback2 and linecache2 packages.  (Robert
    Collins, github #111)
  * "testtools" now depends on "unittest2" 1.0.0 which brings in a
    dependency on "traceback2" and via it "linecache2". (Robert
    Collins)
* Sun Jan 25 2015 arun@gmx.de
- specfile:
  * added unittest2, setuptools requirement
  * remove ifdefs to run tests
- update to version 1.5.0:
  * When an import error happens "testtools.run" will now show the
    full error rather than just the name of the module that failed to
    import.  (Robert Collins)
- changes from version 1.4.0:
  * "testtools.TestCase" now inherits from unittest2.TestCase, which
    provides a "setUpClass" for upcalls on Python 2.6.  (Robert
    Collins, #1393283)
- changes from version 1.3.0:
  * Fixed our setup.py to use setup_requires to ensure the import
    dependencies for testtools are present before setup.py runs (as
    setup.py imports testtools to read out the version
    number). (Robert Collins)
  * Support setUpClass skipping with self.skipException. Previously
    this worked with unittest from 2.7 and above but was not supported
    by testtools - it was a happy accident. Since we now hard depend
    on unittest2, we need to invert our exception lookup priorities to
    support it. Regular skips done through raise self.skipException
    will continue to work, since they were always caught in our code -
    its because the suite type being used to implement setUpClass has
    changed that an issue occured.  (Robert Collins, #1393068)
- changes from version 1.2.1:
  * Correctly express our unittest2 dependency: we don't work with old
    releases.  (Robert Collins)
- changes from version 1.2.0:
  * Depends on unittest2 for discovery functionality and the
    "TestProgram" base class. This brings in many fixes made to
    discovery where previously we were only using the discovery
    package or the version in the release of Python that the test
    execution was occuring on. (Robert Collins, #1271133)
  * Fixed unit tests which were failing under pypy due to a change in
    the way pypy formats tracebacks. (Thomi Richards)
  * Fixed the testtools test suite to run correctly when run via
    "unit2" or "testtools.run discover".
  * Make `testtools.content.text_content` error if anything other than
    text is given as content. (Thomi Richards)
  * We now publish wheels of testtools. (Robert Collins, #issue84)
- changes from version 1.1.0:
  * Exceptions in a "fixture.getDetails" method will no longer mask
    errors raised from the same fixture's "setUp" method.  (Robert
    Collins, #1368440)
- changes from version 1.0.0:
  * Fix a long-standing bug where tearDown and cleanUps would not be
    called if the test run was interrupted. This should fix leaking
    external resources from interrupted tests.  (Robert Collins,
    [#1364188])
  * Fix a long-standing bug where calling sys.exit(0) from within a
    test would cause the test suite to exit with 0, without reporting
    a failure of that test. We still allow the test suite to be exited
    (since catching higher order exceptions requires exceptional
    circumstances) but we now call a last-resort handler on the
    TestCase, resulting in an error being reported for the test.
    (Robert Collins, #1364188)
  * Fix an issue where tests skipped with the "skip"* family of
    decorators would still have their "setUp" and "tearDown"
    functions called.  (Thomi Richards,
    [#]https://github.com/testing-cabal/testtools/issues/86)
  * We have adopted a formal backwards compatibility statement (see
    hacking.rst) (Robert Collins)
- changes from version 0.9.39:
  * Brown paper bag release - 0.9.38 was broken for some users,
    _jython_aware_splitext was not defined entirely compatibly.
    (Robert Collins,
    [#]https://github.com/testing-cabal/testtools/issues/100)
- changes from version 0.9.38:
  * Discovery import error detection wasn't implemented for python 2.6
    (the 'discover' module). (Robert Collins)
  * Discovery now executes load_tests (if present) in __init__ in all
    packages.  (Robert Collins, http://bugs.python.org/issue16662)
- changes from version 0.9.37:
  * "stdout" is now correctly honoured on "run.TestProgram" -
    before the runner objects would be created with no stdout
    parameter. If construction fails, the previous parameter list is
    attempted, permitting compatibility with Runner classes that don't
    accept stdout as a parameter.  (Robert Collins)
  * The "ExtendedToStreamDecorator" now handles content objects with
    one less packet - the last packet of the source content is sent
    with EOF set rather than an empty packet with EOF set being sent
    after the last packet of the source content. (Robert Collins)
- changes from version 0.9.36:
  * Error if "setUp" or "tearDown" are called twice.  (Robert
    Collins, #882884)
  * Make testtools compatible with the "unittest.expectedFailure"
    decorator in Python 3.4. (Thomi Richards)
  * Introduce the assert_that function, which allows matchers to be
    used independent of testtools.TestCase. (Daniel Watkins, #1243834)
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * update copyright year
  * remove ifs for opensuse version <=1220
* Thu Feb 13 2014 speilicke@suse.com
- update to 0.9.35:
  * Removed a number of code paths where Python 2.4 and Python 2.5 were
    explicitly handled. (Daniel Watkins)
  * Added the ``testtools.TestCase.expectThat`` method, which implements
    delayed assertions. (Thomi Richards)
  * Docs are now built as part of the Travis-CI build, reducing the chance of
    Read The Docs being broken accidentally. (Daniel Watkins, #1158773)
* Thu Aug 15 2013 speilicke@suse.com
- Only buildrequire python3-2to3 on 12.2
* Tue Jul  2 2013 speilicke@suse.com
- Introduce a build conditional for running tests to break build cycle
  with python-extras
* Fri Jun 21 2013 speilicke@suse.com
- Use upstream URL
- Run testsuite
- Update to version 0.9.32:
  + Stacktrace filtering no longer hides unittest frames that are surrounded by
    user frames. We will reenable this when we figure out a better algorithm for
    retaining meaning. (Robert Collins, #1188420)
  + The compatibility code for skipped tests with unittest2 was broken.
    (Robert Collins, #1190951)
  + Various documentation improvements (Clint Byrum, Xiao Hanyu).
- Changes from version 0.9.31:
  + ExpectedException now accepts a msg parameter for describing an error,
    much the same as assertEquals etc. (Robert Collins)
* Tue Apr 23 2013 p.drouand@gmail.com
- Fix source URL; packages are available on https://pypi.python.org
* Mon Apr 22 2013 dmueller@suse.com
- update to 0.9.30:
  A new sort of TestResult, the StreamResult has been added, as a prototype for
  a revised standard library test result API.  Expect this API to change.
  Although we will try to preserve compatibility for early adopters, it is
  experimental and we might need to break it if it turns out to be unsuitable.
* Tue Apr 16 2013 p.drouand@gmail.com
- Update to version 0.9.29
  + Added missing build-depends: python3-setuptools, python-setuptools and
    python-extras.
  + Build-depends: python-fixtures must be >= 0.3.12~
- Disable test; it seems there is a typo mistake in setup.cfg
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Tue Jan 15 2013 p.drouand@gmail.com
- Initial python3 support
* Mon Jan 14 2013 saschpe@suse.de
- Update to version 0.9.24:
  * testtools.run discover will now sort the tests it discovered. This is a
    workaround for http://bugs.python.org/issue16709. Non-standard test suites
    are preserved, and their sort_tests() method called (if they have such an
    attribute). testtools.testsuite.sorted_tests(suite, True) can be used by
    such suites to do a local sort.
  * ThreadsafeForwardingResult now defines a stub progress method, which
    fixes testr run of streams containing progress markers (by discarding the
    progress data).
- Changes from version 0.9.23:
  * run.TestToolsTestRunner now accepts the verbosity, buffer and failfast
    arguments the upstream python TestProgram code wants to give it, making it
    possible to support them in a compatible fashion. (Robert Collins)
  * testtools.run now supports the -f or --failfast parameter.
    Previously it was advertised in the help but ignored.
  * AnyMatch added, a new matcher that matches when any item in a collection
    matches the given matcher.
  * Spelling corrections to documentation.
  * TestProgram now has a sane default for its testRunner argument.
  * The test suite passes on Python 3 again.
- Changes from version 0.9.22:
  * content_from_file and content_from_stream now accept seek_offset and
    seek_whence parameters allowing them to be used to grab less than the full
    stream, or to be used with StringIO streams.
* Thu Dec  6 2012 saschpe@suse.de
- Cleanup spec file
- Install HTML documentation
* Tue Nov 13 2012 jfunk@funktronics.ca
- Update to 0.9.21:
  * DirContains correctly exposed, after being accidentally hidden in the
    great matcher re-organization of 0.9.17.  (Jonathan Lange)
- 0.9.20
  * New, powerful matchers that match items in a dictionary:
  - MatchesDict, match every key in a dictionary with a key in a
    dictionary of matchers.  For when the set of expected keys is equal to
    the set of observed keys.
  - ContainsDict, every key in a dictionary of matchers must be
    found in a dictionary, and the values for those keys must match.  For
    when the set of expected keys is a subset of the set of observed keys.
  - ContainedByDict, every key in a dictionary must be found in
    a dictionary of matchers.  For when the set of expected keys is a
    superset of the set of observed keys.
    The names are a little confusing, sorry.  We're still trying to figure out
    how to present the concept in the simplest way possible.
- 0.9.19
  * Include the matcher tests in the release, allowing the tests to run and
    pass from the release tarball.  (Jonathan Lange)
  * Fix cosmetic test failures in Python 3.3, introduced during release
    0.9.17. (Jonathan Lange)
- 0.9.18
  Due to an oversight, release 0.9.18 did not contain the new
  testtools.matchers package and was thus completely broken.  This release
  corrects that, returning us all to normality.
- 0.9.17
  This release brings better discover support and Python3.x improvements.
  There are still some test failures on Python3.3 but they are cosmetic - the
  library is as usable there as on any other Python 3 release.
  * The testtools.matchers package has been split up.  No change to the
    public interface.  (Jonathan Lange)
  * python -m testtools.run discover . --list now works. (Robert Collins)
  * Correctly handling of bytes vs text in JSON content type. (Martin [gz])
- 0.9.16
  This is the first release of testtools to drop support for Python 2.4 and
  2.5. If you need support for either of those versions, please use testtools
  0.9.15.
  * New content helper, json_content (Jonathan Lange)
  * New matchers:
  * ContainsAll for asserting one thing is a subset of another
    (Raphaël Badin)
  * SameMembers for asserting two iterators have the same members.
    (Jonathan Lange)
  * Reraising of exceptions in Python 3 is more reliable. (Martin [gz])
* Wed May 23 2012 jfunk@funktronics.ca
- Update to 0.9.15
  * PlaceHolder and ErrorHolder now support being given result
    details. (Robert Collins)
  * ErrorHolder is now just a function - all the logic is in
    PlaceHolder. (Robert Collins)
  * TestResult and all other TestResult-like objects in testtools
    distinguish between global tags and test-local tags, as per the subunit
    specification.  (Jonathan Lange)
  * This is the **last** release of testtools that supports Python 2.4 or 2.5.
    These releases are no longer supported by the Python community and do not
    receive security updates. If this affects you, you will need to either
    stay on this release or perform your own backports.
    (Jonathan Lange, Robert Collins)
  * ThreadsafeForwardingResult now forwards global tags as test-local
    tags, making reasoning about the correctness of the multiplexed stream
    simpler. This preserves the semantic value (what tags apply to a given
    test) while consuming less stream size (as no negative-tag statement is
    needed). (Robert Collins, Gary Poster, #986434)
  * API documentation corrections. (Raphaël Badin)
  * ConcurrentTestSuite now takes an optional wrap_result parameter
    that can be used to wrap the ThreadsafeForwardingResults created by
    the suite.  (Jonathan Lange)
  * Tagger added.  It's a new TestResult that tags all tests sent to
    it with a particular set of tags.  (Jonathan Lange)
  * testresultdecorator brought over from subunit.  (Jonathan Lange)
  * All TestResult wrappers now correctly forward current_tags from
    their wrapped results, meaning that current_tags can always be relied
    upon to return the currently active tags on a test result.
  * TestByTestResult, a TestResult that calls a method once per test,
    added.  (Jonathan Lange)
  * ThreadsafeForwardingResult correctly forwards tags() calls where
    only one of new_tags or gone_tags are specified.
    (Jonathan Lange, #980263)
  * ThreadsafeForwardingResult no longer leaks local tags from one test
    into all future tests run.  (Jonathan Lange, #985613)
  * ThreadsafeForwardingResult has many, many more tests. (Jonathan Lange)
- Enable tests
* Tue Feb 21 2012 jfunk@funktronics.ca
- Update to 0.9.14:
  * Our sister project, subunit <https://launchpad.net/subunit>_, was using
    a private API that was deleted in the 0.9.13 release. This release
    restores that API in order to smooth out the upgrade path.
    If you don't use subunit, then this release won't matter very much to you.
- 0.9.13
  - Changes
  * MatchesAll now takes an first_only keyword argument that changes
    how mismatches are displayed. If you were previously passing matchers to
    MatchesAll with keyword arguments, then this change might affect
    your test results. (Jonathan Lange)
  - Improvements
  * Actually hide all of the testtools stack for assertion failures. The
    previous release promised clean stack, but now we actually provide it.
    (Jonathan Lange, #854769)
  * assertRaises now includes the repr of the callable that failed
    to raise properly. (Jonathan Lange, #881052)
  * Asynchronous tests no longer hang when run with trial.
    (Jonathan Lange, #926189)
  * Content objects now have an as_text method to convert their
    contents to Unicode text.  (Jonathan Lange)
  * Failed equality assertions now line up. (Jonathan Lange, #879339)
  * FullStackRunTest no longer aborts the test run if a test raises an
    error.  (Jonathan Lange)
  * MatchesAll and MatchesListwise both take a first_only
    keyword argument.  If True, they will report only on the first mismatch
    they find, and not continue looking for other possible mismatches.
    (Jonathan Lange)
  * New helper, Nullary that turns callables with arguments into ones
    that don't take arguments.  (Jonathan Lange)
  * New matchers:
  * DirContains matches the contents of a directory.
    (Jonathan Lange, James Westby)
  * DirExists matches if a directory exists.
    (Jonathan Lange, James Westby)
  * FileContains matches the contents of a file.
    (Jonathan Lange, James Westby)
  * FileExists matches if a file exists.
    (Jonathan Lange, James Westby)
  * HasPermissions matches the permissions of a file. (Jonathan Lange)
  * MatchesPredicate matches if a predicate is true. (Jonathan Lange)
  * PathExists matches if a path exists. (Jonathan Lange, James
    Westby)
  * SamePath matches if two paths are the same. (Jonathan Lange)
  * TarballContains matches the contents of a tarball. (Jonathan
    Lange)
  * MultiTestResult supports the tags method.
    (Graham Binns, Francesco Banconi, #914279)
  * ThreadsafeForwardingResult supports the tags method.
    (Graham Binns, Francesco Banconi, #914279)
  * ThreadsafeForwardingResult no longer includes semaphore acquisition
    time in the test duration (for implicitly timed test runs).
    (Robert Collins, #914362)
* Sun Dec 11 2011 jfunk@funktronics.ca
- Update to 0.9.12:
  - Changes:
  * AfterPreproccessing renamed to AfterPreprocessing, which is a
    more correct spelling. Old name preserved for backwards compatibility,
    but is now deprecated.  Please stop using it.  (Jonathan Lange, #813460)
  * assertThat raises MismatchError instead of
    TestCase.failureException.  MismatchError is a subclass of
    AssertionError, so in most cases this change will not matter.
    However, if self.failureException has been set to a non-default
    value, then mismatches will become test errors rather than test
    failures.
  * gather_details takes two dicts, rather than two detailed objects.
    (Jonathan Lange, #801027)
  * MatchesRegex mismatch now says "<value> does not match /<regex>/"
    rather than "<regex> did not match <value>". The regular expression
    contains fewer backslashes too. (Jonathan Lange, #818079)
  * Tests that run with AsynchronousDeferredRunTest now have the
    reactor attribute set to the running reactor. (Jonathan Lange,
    [#720749])
  - Improvements:
  * All public matchers are now in testtools.matchers.__all__. (Jonathan
    Lange, #784859)
  * assertThat can actually display mismatches and matchers that contain
    extended unicode characters. (Jonathan Lange, Martin [gz], #804127)
  * assertThat output is much less verbose, displaying only what the
    mismatch tells us to display. Old-style verbose output can be had by
    passing verbose=True to assertThat. (Jonathan Lange, #675323,
    [#593190])
  * assertThat accepts a message which will be used to annotate the
    matcher. This can be given as a third parameter or as a keyword
    parameter. (Robert Collins)
  * Automated the Launchpad part of the release process. (Jonathan Lange,
    [#623486])
  * Correctly display non-ASCII unicode output on terminals that claim to
    have a unicode encoding. (Martin [gz], #804122)
  * DocTestMatches correctly handles unicode output from examples,
    rather than raising an error. (Martin [gz], #764170)
  * ErrorHolder and PlaceHolder added to docs. (Jonathan Lange,
    [#816597])
  * ExpectedException now matches any exception of the given type by
    default, and also allows specifying a Matcher rather than a mere
    regular expression. (Jonathan Lange, #791889)
  * FixtureSuite added, allows test suites to run with a given fixture.
    (Jonathan Lange)
  * Hide testtools's own stack frames when displaying tracebacks, making it
    easier for test authors to focus on their errors. (Jonathan Lange,
    Martin [gz], #788974)
  * Less boilerplate displayed in test failures and errors. (Jonathan Lange,
    [#660852])
  * MatchesException now allows you to match exceptions against any
    matcher, rather than just regular expressions. (Jonathan Lange, #791889)
  * MatchesException now permits a tuple of types rather than a single
    type (when using the type matching mode). (Robert Collins)
  * MatchesStructure.byEquality added to make the common case of
    matching many attributes by equality much easier.
    MatchesStructure.byMatcher added in case folk want to match by
    things other than equality. (Jonathan Lange)
  * New convenience assertions, assertIsNone and assertIsNotNone.
    (Christian Kampka)
  * New matchers:
  * AllMatch matches many values against a single matcher. (Jonathan
    Lange, #615108)
  * Contains. (Robert Collins)
  * GreaterThan. (Christian Kampka)
  * New helper, safe_hasattr added. (Jonathan Lange)
  * reraise added to testtools.compat. (Jonathan Lange)
- 0.9.11:
  - Changes
  * TestCase now uses super to call base unittest.TestCase
    constructor, setUp and tearDown. (Tim Cole, #771508)
  * If, when calling useFixture an error occurs during fixture set up,
    we still attempt to gather details from the fixture. (Gavin Panella)
  - Improvements
  * Additional compat helper for BytesIO for libraries that build on
    testtools and are working on Python 3 porting. (Robert Collins)
  * Corrected documentation for MatchesStructure in the test authors
    document. (Jonathan Lange)
  * LessThan error message now says something that is logically correct.
    (Gavin Panella, #762008)
  * Multiple details from a single fixture are now kept separate, rather
    than being mooshed together. (Gavin Panella, #788182)
  * Python 3 support now back in action. (Martin [gz], #688729)
  * try_import and try_imports have a callback that is called
    whenever they fail to import a module. (Martin Pool)
* Sat Apr 16 2011 jfunk@funktronics.ca
- Initial release
